@@ -1,20 +1,32 @@
 package IPC::Door::Server;
-#$Id: Server.pm,v 1.12 2004/05/06 06:40:54 asari Exp $
+
+#$Id: Server.pm 37 2005-06-07 05:50:05Z asari $
 
 use 5.006;
 use strict;
 use warnings;
 
 use POSIX qw[ :fcntl_h ];
-use IPC::Door;
+use IPC::Door qw( :attr );
 
 our @ISA = qw[ IPC::Door ];
 
+sub revoke {
+    my $self = shift;
+    my $path = $self->{'path'};
+
+    return undef unless $self->is_door;
+
+    $self->__revoke($path);
+
+    1;
+}
+
 sub DESTROY {
     my $self = shift;
 
     $self->SUPER::DESTROY;
-    unlink $self->{'path'} if (-e $self->{'path'});
+    unlink $self->{'path'} if ( -e $self->{'path'} );
 }
 
 1;    # end of IPC::Door::Server
@@ -54,20 +66,17 @@ See <IPC::Door/"KNOWN ISSUES">.
 
 =head2 SPECIAL VARIABLES
 
-Once a door client calls an C<IPC::Door::Server> object, it sets 5
-special variables as a result of C<door_cred>(3DOOR) call.
-These are:
-C<$main::DOOR_CLIENT_EUID>,
-C<$main::DOOR_CLIENT_EGID>,
-C<$main::DOOR_CLIENT_RUID>,
-C<$main::DOOR_CLIENT_RGID>,
-C<$main::DOOR_CLIENT_PID>,
-and their meanings should be pretty self-explanatory.
+When an C<IPC::Door::Client> process makes a call, the
+C<IPC::Door::Server> process sets 5 special variables as a result of
+C<door_cred>/C<doore_ucred> (3DOOR) call.
+These corresponds to self-explanatory credentials of the client process:
+C<$IPC::Door::CLIENT_EUID>,
+C<$IPC::Door::CLIENT_EGID>,
+C<$IPC::Door::CLIENT_RUID>,
+C<$IPC::Door::CLIENT_RGID>, and
+C<$IPC::Door::CLIENT_PID>.
 
-If it makes sense, you can discriminate against client processes
-inside C<&mysub>.
-(It doesn't make much sense to do anything with these variables outside
-&mysub, anyway.)
+(These names may change in the future releases of this module.)
 
 =head1 SEE ALSO
 
@@ -81,7 +90,7 @@ L<http://www.asari.net/perl>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2003, 2004 by ASARI Hirotsugu
+Copyright 2003-2005 by ASARI Hirotsugu
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself. 
