@@ -1,25 +1,25 @@
-#!PERL -w
-# $Id: door-server2.pl,v 1.9 2004/05/23 04:30:04 asari Exp $
-
-# this script will be forked and exec'd by 09-client-server2.t
+#!/usr/bin/perl -w
+# $Id: door-server2.pl 35 2005-06-06 04:48:39Z asari $
 
 use strict;
 use Fcntl;
-use Devel::Peek;
 use Data::Dumper;
 use blib;
 
+use Storable qw/freeze thaw/;
+
 use File::Basename;
 my ( $base, $path, $suffix ) = fileparse( $0, qr(\.pl$) );
 
 $SIG{INT}  = \&term;
 $SIG{TERM} = \&term;
 
-#$SIG{__WARN__} = \&term;
-
 use IPC::Door::Server;
-my $door = $path . 'DOOR';
+my $door = $path . 'DOOR2';
 
+open OUT, $path."out";
+select OUT;
+if (-f $door) { unlink $door };
 check_door($door);
 
 our $ok_to_die = 0;
@@ -27,8 +27,6 @@ our $ok_to_die = 0;
 my $server = new IPC::Door::Server( $door, \&serv )
   || die "Cannot create $door: $!\n";
 
-#Dump($server);
-
 while ( !($ok_to_die) ) {
     die "$door disappeared\n" unless IPC::Door::is_door($door);
     sysopen( DOOR, $door, O_WRONLY ) || die "Can't write to $door: $!\n";
@@ -36,26 +34,17 @@ while ( !($ok_to_die) ) {
     select undef, undef, undef, 0.2;
 }
 
-#####################################################
-#
-# subroutines
-#
-#####################################################
 sub term {
     my $sig = shift;
     $ok_to_die = 1;
-#    unlink $door || warn "Can't remove $door.\n";
-
-    #	print STDERR "$0: Caught signal $sig.\n";
 }
 
 sub serv {
     my $arg = shift;
-#    print "&serv's argument: $arg\n";
 
-    $arg =~ s/_/-/g;
+    my @ans = reverse( @{thaw($arg)} );
 
-    return $arg;
+    return freeze \@ans;
 }
 
 sub check_door {
